@@ -16,10 +16,8 @@
 Depend on @rules_python//python/runfiles instead and refer to its documentation:
 https://github.com/bazelbuild/rules_python/blob/main/python/runfiles/README.md
 """
-from python.runfiles import Create as _Create
-from python.runfiles import CreateDirectoryBased as _CreateDirectoryBased
-from python.runfiles import CreateManifestBased as _CreateManifestBased
+from python.runfiles import runfiles
 
-Create = _Create
-CreateDirectoryBased = _CreateDirectoryBased
-CreateManifestBased = _CreateManifestBased
+Create = runfiles.Create
+CreateDirectoryBased = runfiles.CreateDirectoryBased
+CreateManifestBased = runfiles.CreateManifestBased
