@@ -332,6 +332,12 @@ bool IsReadableFile(const Path& p) {
   return true;
 }
 
+bool DirectoryExists(const Path& p) {
+  DWORD attrs = GetFileAttributesW(AddUncPrefixMaybe(p).c_str());
+  return attrs != INVALID_FILE_ATTRIBUTES &&
+         ((attrs & FILE_ATTRIBUTE_DIRECTORY) != 0);
+}
+
 // Gets an environment variable's value.
 // Returns:
 // - true, if the envvar is defined and successfully fetched, or it's empty or
@@ -469,6 +475,14 @@ bool ChdirToRunfiles(const Path& abs_exec_root, const Path& abs_test_srcdir) {
   // dependencies.
   std::wstring coverage_dir;
   if (!GetEnv(L"COVERAGE_DIR", &coverage_dir) || coverage_dir.empty()) {
+    if (!DirectoryExists(dir)) {
+      LogError(
+          __LINE__,
+          L"ERROR: RUNFILES_DIR does not exist. This can happen when using "
+          L"--nobuild_runfile_manifests with local execution. Use a different "
+          L"execution strategy, or build with runfile manifests.");
+      return false;
+    }
     if (!SetCurrentDirectoryW(dir.Get().c_str())) {
       DWORD err = GetLastError();
       LogErrorWithArgAndValue(__LINE__, "Could not chdir", dir.Get(), err);
@@ -1685,49 +1699,11 @@ std::string CreateErrorTag(int exit_code) {
   }
 }
 
-bool ShouldCreateXml(const Path& xml_log, const MainType main_type,
-                     bool* result) {
-  *result = true;
-
-  // If running from the xml generator binary, we should always create the xml
-  // file.
-  if (main_type == MainType::kXmlWriterMain) {
-    return true;
-  }
-
-  DWORD attr = GetFileAttributesW(AddUncPrefixMaybe(xml_log).c_str());
-  if (attr != INVALID_FILE_ATTRIBUTES) {
-    // The XML file already exists, maybe the test framework wrote it.
-    // Leave the file alone.
-    *result = false;
-    return true;
-  }
-
-  std::wstring split_xml_generation;
-  if (!GetEnv(L"EXPERIMENTAL_SPLIT_XML_GENERATION", &split_xml_generation)) {
-    LogError(__LINE__, "Failed to get %EXPERIMENTAL_SPLIT_XML_GENERATION%");
-    return false;
-  }
-  if (split_xml_generation == L"1") {
-    // Bazel generates the test xml as a separate action, so we don't have to
-    // create it.
-    *result = false;
-  }
-
-  return true;
-}
-
 bool CreateXmlLog(const Path& output, const Path& test_outerr,
                   const Duration duration, const int exit_code,
                   const DeleteAfterwards delete_afterwards,
                   const MainType main_type) {
-  bool should_create_xml;
-  if (!ShouldCreateXml(output, main_type, &should_create_xml)) {
-    LogErrorWithArg(__LINE__, "Failed to decide if XML log is needed",
-                    output.Get());
-    return false;
-  }
-  if (!should_create_xml) {
+  if (main_type != MainType::kXmlWriterMain) {
     return true;
   }
 
